@@ -5,14 +5,14 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-use Data::Sah;
+use Data::Sah::Normalize qw(normalize_schema);
 use Function::Fallback::CoreOrPP qw(clone);
 
 use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_args_from_array);
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 our %SPEC;
 
@@ -83,7 +83,7 @@ sub get_args_from_array {
     if (!$args_p) {
         $args_p = clone($meta->{args} // {});
         while (my ($a, $as) = each %$args_p) {
-            $as->{schema} = Data::Sah::normalize_schema($as->{schema} // 'any');
+            $as->{schema} = normalize_schema($as->{schema} // 'any');
         }
     }
     my $allow_extra_elems = $input_args{allow_extra_elems} // 0;
@@ -135,7 +135,7 @@ Perinci::Sub::GetArgs::Array - Get subroutine arguments from array
 
 =head1 VERSION
 
-version 0.12
+This document describes version 0.13 of Perinci::Sub::GetArgs::Array (from Perl distribution Perinci-Sub-GetArgs-Array), released on 2014-07-08.
 
 =head1 SYNOPSIS
 
